==> openwebbeans-1.2.8-source-release.zip: openwebbeans-1.2.8/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/OwbApplication.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.jsf;

import javax.el.ExpressionFactory;
import javax.faces.application.Application;
import javax.faces.application.ApplicationWrapper;

import org.apache.webbeans.config.WebBeansContext;

public class OwbApplication extends ApplicationWrapper
{
    private Application wrappedApplication;
    
    private volatile ExpressionFactory expressionFactory;
    
    public OwbApplication(Application wrappedApplication)
    {
        this.wrappedApplication = wrappedApplication;
    }


    /* (non-Javadoc)
     * @see javax.faces.application.Application#getExpressionFactory()
     */
    @Override
    public ExpressionFactory getExpressionFactory()
    {
        if(expressionFactory == null)
        {
            expressionFactory = wrappedApplication.getExpressionFactory();
            expressionFactory = WebBeansContext.getInstance().getBeanManagerImpl().wrapExpressionFactory(expressionFactory);
        }
        
        return expressionFactory;
    }


    @Override
    public Application getWrapped()
    {
        return wrappedApplication;
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-jsf/src/main/java/org/apache/webbeans/jsf/OwbApplication.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.jsf;

import jakarta.el.ExpressionFactory;
import jakarta.faces.application.Application;
import jakarta.faces.application.ApplicationWrapper;

import org.apache.webbeans.config.WebBeansContext;

public class OwbApplication extends ApplicationWrapper
{
    private Application wrappedApplication;
    
    private volatile ExpressionFactory expressionFactory;
    
    public OwbApplication(Application wrappedApplication)
    {
        this.wrappedApplication = wrappedApplication;
    }


    /* (non-Javadoc)
     * @see jakarta.faces.application.Application#getExpressionFactory()
     */
    @Override
    public ExpressionFactory getExpressionFactory()
    {
        if(expressionFactory == null)
        {
            expressionFactory = wrappedApplication.getExpressionFactory();
            expressionFactory = WebBeansContext.getInstance().getBeanManagerImpl().wrapExpressionFactory(expressionFactory);
        }
        
        return expressionFactory;
    }


    @Override
    public Application getWrapped()
    {
        return wrappedApplication;
    }
}
